import { ref, computed } from 'vue';
import '../../../hooks/index.mjs';
import '../../../utils/index.mjs';
import { useAttrs } from '../../../hooks/use-attrs/index.mjs';
import { isNumber } from '@vueuse/core';

const ROW_SPAN = 24;
const defaultSpan = 6;
const _defineSlotKey = "slot";
const _customAttr = ["columns", "gutter"];
const useGetColumns = (props) => {
  const _res = ref([]);
  const { columns = [] } = props;
  if (Array.isArray(columns)) {
    _res.value = columns;
  }
  return _res;
};
const useCheckComShow = (item, name) => {
  const { slotKey, itemType, modelKey } = item;
  if (slotKey)
    return name === _defineSlotKey;
  return itemType === name && !!modelKey;
};
const useGetFormAttr = () => {
  const _attr = useAttrs({ excludeKeys: computed(() => _customAttr) });
  return _attr;
};
const useGetFormItemAttr = (v) => {
  var _a;
  return (_a = v == null ? void 0 : v.formItemProps) != null ? _a : {};
};
const useActionIsRight = (item) => {
  const { itemType, slotKey, actionFixedRight = true } = item;
  return slotKey === "action" && itemType === "custom" && actionFixedRight;
};
const useVaildJustify = (item, jus) => {
  const { justify = "left" } = item;
  return justify === jus;
};
const useGetActionItemSpan = (columns, index) => {
  const _columns = columns.slice(0, index);
  let count = 0;
  _columns.forEach((item) => {
    const { span = defaultSpan } = item;
    const _count = count + span;
    if (_count === ROW_SPAN)
      return count = 0;
    if (_count > ROW_SPAN)
      return count = span;
    count += span;
  });
  return ROW_SPAN - count;
};
const useGetItemSpan = (columns, item, index) => {
  const { span } = item;
  if (isNumber(span))
    return span;
  if (useActionIsRight(item))
    return useGetActionItemSpan(columns, index);
  return defaultSpan;
};
const useGetItemOriginCfg = (obj) => {
  return obj != null ? obj : {};
};

export { useActionIsRight, useCheckComShow, useGetActionItemSpan, useGetColumns, useGetFormAttr, useGetFormItemAttr, useGetItemOriginCfg, useGetItemSpan, useVaildJustify };
//# sourceMappingURL=use-mg-form.mjs.map
